{%- extends "manhattan/manage/generics/list.html" -%} {%- import "manhattan/manage/components/changes.html" as _changes -%} {% macro headings() -%} {{ _results.heading('Type') }} {{ _results.heading('Date/Time') }} {{ _results.heading('User') }} {{ _results.heading('Details') }} {%- endmacro %} {% macro columns(item) -%} {{ _results.column(item.type) }} {{ _results.column(item.created|humanize_datetime) }} {{ _results.column(item.user_sticky_label) }} {% call _results.column() %} {{ _changes.changes(item.details) }} {% endcall %} {%- endmacro %}